/******************************************************************************
 *
 * File: DTMFLib.h
 *
 * Description:
 *		DTMF library APIs for Sony CLIE
 *		This library supports only Sony CLIE device
 *		which has PCM/FM feature.
 *
 *  Copyright (c) 2002 Hiroyuki Okamoto
 *  All rights reserved.
 *  http://hokamoto.tripod.com/
 *
 *****************************************************************************/

#ifndef __DTMF_LIB_H__
#define __DTMF_LIB_H__

#ifdef BUILDING_DTMF_LIB
	#define DTMF_LIB_TRAP(trapNum)
#else
	#define DTMF_LIB_TRAP(trapNum) SYS_TRAP(trapNum)
#endif


// Palm OS common definitions
#include <PalmTypes.h>
#include <SystemResources.h>


/********************************************************************
 * Type and creator of DTMF Library database
 ********************************************************************/
#define		dtmfLibCreatorID	'DLfC'				// DTMF Library database creator
#define		dtmfLibTypeID		'libr'				// Standard library database type


/********************************************************************
 * Internal library name for SysLibFind()
 ********************************************************************/
#define		DTMFLibName			"DTMFLib"		


/************************************************************
 * DTMF Library Error codes
 *************************************************************/

#define dtmfErrParam			(appErrorClass | 1)		// invalid parameter
#define dtmfErrNotOpen			(appErrorClass | 2)		// library is not open
#define dtmfErrStillOpen		(appErrorClass | 3)		// returned from DTMFLibClose() if
									// the library is still open by others
#define dtmfErrMemory			(appErrorClass | 4)		// memory error occurred


typedef enum {
	dtmfLibTrapGetLibAPIVersion = sysLibTrapCustom,
	dtmfLibTrapPlayChar,
	dtmfLibTrapPlayStr,
	
	dtmfLibTrapLast
	} dtmfLibTrapNumberEnum;

/********************************************************************
 * API Prototypes
 ********************************************************************/

#ifdef __cplusplus
extern "C" {
#endif


//--------------------------------------------------
// Standard library open, close, sleep and wake functions
//--------------------------------------------------

extern Err DTMFLibOpen(UInt16 refNum, UInt32 * ctxP)
				DTMF_LIB_TRAP(sysLibTrapOpen);
				
extern Err DTMFLibClose(UInt16 refNum, UInt32 ctx)
				DTMF_LIB_TRAP(sysLibTrapClose);

extern Err DTMFLibSleep(UInt16 refNum)
				DTMF_LIB_TRAP(sysLibTrapSleep);

extern Err DTMFLibWake(UInt16 refNum)
				DTMF_LIB_TRAP(sysLibTrapWake);


//--------------------------------------------------
// library API functions
//--------------------------------------------------
	
// Get library API version
extern Err DTMFLibGetLibAPIVersion(UInt16 refNum, UInt32 * dwVerP)
				DTMF_LIB_TRAP(dtmfLibTrapGetLibAPIVersion);

// Play one DTMF tone	
extern Err DTMFLibPlayChar(UInt16 refNum, UInt32 ctx, char ascChar, Int16 toneLength, UInt16 amplitude)
				DTMF_LIB_TRAP(dtmfLibTrapPlayChar);

// Play multiple DTMF tones sequentially.	
extern Err DTMFLibPlayStr(UInt16 refNum, UInt32 ctx, char *ascStr, Int16 toneLength, Int16 toneGap, UInt16 amplitude)
				DTMF_LIB_TRAP(dtmfLibTrapPlayStr);

// For loading the library in Palm OS Mac emulation mode
extern Err DTMFLibInstall(UInt16 refNum, SysLibTblEntryPtr entryP);


#ifdef __cplusplus 
}
#endif


#endif	// __DTMF_LIB_H__

